pub struct GcpRuntimePermissionsGenerator;Expand description
GCP runtime permissions generator for custom roles and IAM bindings
Implementations
Sourceimpl GcpRuntimePermissionsGenerator
impl GcpRuntimePermissionsGenerator
Sourcepub fn generate_custom_role(
&self,
permission_set: &PermissionSet,
context: &PermissionContext,
) -> Result<GcpCustomRole>
pub fn generate_custom_role( &self, permission_set: &PermissionSet, context: &PermissionContext, ) -> Result<GcpCustomRole>
Generate a GCP custom role from a permission set
Takes a PermissionSet and produces GCP custom role definitions that can be created at runtime.
Sourcepub fn generate_bindings(
&self,
permission_set: &PermissionSet,
binding_target: BindingTarget,
context: &PermissionContext,
) -> Result<GcpIamBindings>
pub fn generate_bindings( &self, permission_set: &PermissionSet, binding_target: BindingTarget, context: &PermissionContext, ) -> Result<GcpIamBindings>
Generate IAM bindings from permission set and binding target
Takes a PermissionSet and binding target, produces GCP IAM bindings that can be applied to resources at runtime.